@@ -1,7 +1,7 @@
 
 package CPAN::DistnameInfo;
 
-$VERSION = "0.03";
+$VERSION = "0.05";
 use strict;
 
 sub distname_info {
@@ -58,15 +58,16 @@ sub new {
   my $class = shift;
   my $distfile = shift;
 
-  my %info;
-
   $distfile =~ s,//+,/,g;
 
+  my %info = ( pathname => $distfile );
+
   ($info{filename} = $distfile) =~ s,^(((.*?/)?authors/)?id/)?([A-Z])/(\4[A-Z])/(\5[-A-Z]*)/,,
     and $info{cpanid} = $6;
 
-  if ($distfile =~ m,([^/]+)\.(?:tar\.g?z|zip|tgz)$,i) { # support more ?
+  if ($distfile =~ m,([^/]+)\.(tar\.g?z|zip|tgz)$,i) { # support more ?
     $info{distvname} = $1;
+    $info{extension} = $2;
   }
 
   @info{qw(dist version beta)} = distname_info($info{distvname});
@@ -81,6 +82,8 @@ sub maturity  { shift->{maturity} }
 sub filename  { shift->{filename} }
 sub cpanid    { shift->{cpanid} }
 sub distvname { shift->{distvname} }
+sub extension { shift->{extension} }
+sub pathname  { shift->{pathname} }
 
 sub properties { %{ $_[0] } }
 
@@ -104,6 +107,8 @@ CPAN::DistnameInfo - Extract distribution name and version from a distribution f
   my $filename  = $d->filename;  # "CPAN-DistnameInfo-0.02.tar.gz"
   my $cpanid    = $d->cpanid;    # "GBARR"
   my $distvname = $d->distvname; # "CPAN-DistnameInfo-0.02"
+  my $extension = $d->extension; # "tar.gz"
+  my $pathname  = $d->pathname;  # "authors/id/G/GB/GBARR/..."
 
   my %prop = $d->properties;
 
@@ -148,6 +153,14 @@ that was passed in.
 
 The maturity of the distribution. This will be either C<released> or C<developer>
 
+=item extension
+
+The extension of the distribution, often used to denote the archive type (e.g. 'tar.gz')
+
+=item pathname
+
+The pathname that was passed to the constructor when creating the object.
+
 =item properties
 
 This will return a list of key-value pairs, suitable for assigning to a hash,
